# Copyright 1999-2017. Plesk International GmbH. All rights reserved.
""" utility wrapper for composer to execute it under specified system user. """
import sys
import os
import os.path
import subprocess
from optparse import OptionParser
from plesk_exec import drop_privileges

import plesk_log; plesk_log.setDefaultLevel('warning')
log = plesk_log.getLogger(__name__)

CLIENT_PHP_BIN = "/opt/psa/bin/php-cli"
COMPOSER_BIN = "/usr/lib/plesk-9.0/composer.phar"

def doMain(argv):
    parser = OptionParser(usage="Usage: %prog --user <username> [--php <php_interpreter>] -- <composer args>")
    parser.add_option("-u", "--user", help="system user")
    parser.add_option("-p", "--php", help="path to php interpreter")
    (options, args) = parser.parse_args()

    drop_privileges(options.user, "psacln")

    php_bin = CLIENT_PHP_BIN
    proc_env = os.environ.copy()
    if options.php:
        php_bin = options.php
        # modify environment so all php-scripts with "#!/usr/bin/env php" launched by composer will use correct php
        proc_env["PATH"] = os.path.dirname(php_bin) + ":" + proc_env["PATH"]

    cmd = [COMPOSER_BIN] + args
    if os.path.exists("/bin/cagefs_enter"):
        cmd = ["/bin/cagefs_enter"] + cmd
    proc = subprocess.Popen(cmd, env=proc_env)
    proc.communicate()
    sys.exit(proc.returncode)

def main():
    try:
        doMain(sys.argv)
    except SystemExit:
        raise
    except Exception as ex:
        log.error('%s', ex)
        log.debug('This exception happened at:', exc_info=sys.exc_info())
        sys.exit(1)

if __name__ == '__main__':
    main()

# vim: ts=4 sts=4 sw=4 et :
