# Copyright 1999-2017. Plesk International GmbH. All rights reserved.

import stat
import logging as log


class FileStat:
    REG = 'file'
    DIR = 'directory'
    LNK = 'symlink'
    SCK = 'socket'
    CHR = 'chardevice'
    FIFO = 'namedpipe'

    perms = None
    user = None
    group = None
    typ = None
    link_to = None

    def __init__(self, perms=None, user=None, group=None, typ=None, link_to=None, mode=None):
        if mode:
            # Note that fields perms and typ may be set by this method
            self._set_mode(mode)
        if perms:
            self.perms = perms
        self.user = user
        self.group = group
        if typ:
            self.typ = typ
        self.link_to = link_to

    def __str__(self):
        s = "%s %s:%s %s" % (self.perms, self.user, self.group, self.typ)
        if self.typ == FileStat.LNK:
            s += " -> " + self.link_to
        return s

    def __eq__(self, other):
        return all([
            self.perms == other.perms,
            self.user == other.user,
            self.group == other.group,
            self.typ == other.typ,
            self.link_to == other.link_to,
        ])

    def _set_mode(self, mode):
        if not isinstance(mode, int):
            mode = int(mode, 8)
        self.perms = oct(mode & 07777)
        if stat.S_ISLNK(mode):
            self.typ = FileStat.LNK
        elif stat.S_ISREG(mode):
            self.typ = FileStat.REG
        elif stat.S_ISDIR(mode):
            self.typ = FileStat.DIR
        elif stat.S_ISSOCK(mode):
            self.typ = FileStat.SCK
        elif stat.S_ISCHR(mode):
            self.typ = FileStat.CHR
        elif stat.S_ISFIFO(mode):
            self.typ = FileStat.FIFO
        else:
            self.typ = None
            log.warning("Unknown file mode: %s" % oct(mode))

# vim: ts=4 sts=4 sw=4 et :
